--- a/rocAL/source/decoders/image/hw_jpeg_decoder.cpp	2024-11-15 21:55:44.000000000 +0200
+++ b/rocAL/source/decoders/image/hw_jpeg_decoder.cpp	2025-01-15 16:57:20.977446184 +0200
@@ -138,7 +138,11 @@
         ERR("HardwareJpegDecoder::Initialize av_find_stream_info error");
         return Status::HEADER_DECODE_FAILED;
     }
-    ret = av_find_best_stream(_fmt_ctx, AVMEDIA_TYPE_VIDEO, -1, -1, &_decoder, 0);
+    #if LIBAVCODEC_VERSION_INT < AV_VERSION_INT(58, 9, 100)
+	ret = av_find_best_stream(_fmt_ctx, AVMEDIA_TYPE_VIDEO, -1, -1, &_decoder, 0);
+    #else
+	ret = av_find_best_stream(_fmt_ctx, AVMEDIA_TYPE_VIDEO, -1, -1, (const AVCodec **)(&_decoder), 0);
+    #endif
     if (ret < 0) {
         ERR("HardwareJpegDecoder::Initialize Could not find %s stream in input file " +
             STR(av_get_media_type_string(AVMEDIA_TYPE_VIDEO)));
--- a/rocAL/source/decoders/video/ffmpeg_video_decoder.cpp	2024-11-15 21:55:44.000000000 +0200
+++ b/rocAL/source/decoders/video/ffmpeg_video_decoder.cpp	2025-01-15 17:04:47.875374227 +0200
@@ -158,7 +158,7 @@
     }
 
     // find decoder for the stream
-    _decoder = avcodec_find_decoder(_video_stream->codecpar->codec_id);
+    auto _decoder = avcodec_find_decoder(_video_stream->codecpar->codec_id);
     if (!_decoder) {
         ERR("Failed to find " +
             STR(av_get_media_type_string(AVMEDIA_TYPE_VIDEO)) + " codec");
--- a/rocAL/source/decoders/video/hardware_video_decoder.cpp	2024-11-15 21:55:44.000000000 +0200
+++ b/rocAL/source/decoders/video/hardware_video_decoder.cpp	2025-01-15 17:05:28.644367620 +0200
@@ -175,7 +175,12 @@
         ERR("HardWareVideoDecoder::Initialize av_find_stream_info error");
         return Status::FAILED;
     }
-    ret = av_find_best_stream(_fmt_ctx, AVMEDIA_TYPE_VIDEO, -1, -1, &_decoder, 0);
+    #if LIBAVCODEC_VERSION_INT < AV_VERSION_INT(58, 9, 100)
+        ret = av_find_best_stream(_fmt_ctx, AVMEDIA_TYPE_VIDEO, -1, -1, &_decoder, 0);
+    #else
+        ret = av_find_best_stream(_fmt_ctx, AVMEDIA_TYPE_VIDEO, -1, -1, (const AVCodec **)(&_decoder), 0);
+    #endif
+
     if (ret < 0) {
         ERR("HardWareVideoDecoder::Initialize Could not find %s stream in input file " +
             STR(av_get_media_type_string(AVMEDIA_TYPE_VIDEO)) + " " + STR(src_filename));
@@ -203,7 +208,7 @@
     }
 
     // find decoder for the stream
-    _decoder = avcodec_find_decoder(_video_stream->codecpar->codec_id);
+    auto _decoder = avcodec_find_decoder(_video_stream->codecpar->codec_id);
     if (!_decoder) {
         ERR("HardWareVideoDecoder::Initialize Failed to find " +
             STR(av_get_media_type_string(AVMEDIA_TYPE_VIDEO)) + " codec");
